@@ -1,4 +1,4 @@
-##############################################################################
+ ##############################################################################
 #
 # COREBlog.py
 # Classes for COREBlog Site
@@ -84,10 +84,10 @@ from Products.PythonScripts import PythonScript
 
 
 __doc__="""Zope Blog Product 'COREBlog:COREBlog'
-$Id: COREBlog.py,v 1.12 2005/05/02 16:18:45 ats_shib Exp $"""
+$Id: COREBlog.py,v 1.6 2005/02/21 05:42:09 ats_shib Exp $"""
 
-__version__='$Revision: 1.12 $'[11:-2]
-__product_version__ = "COREBlog 1.2"
+__version__='$Revision: 1.6 $'[11:-2]
+__product_version__ = "COREBlog 1.11"
 
 
 manage_addCOREBlogForm=HTMLFile('dtml/manage_addCOREBlogForm',globals())
@@ -269,9 +269,6 @@ class COREBlog(ZCatalog.ZCatalog):
 
         #Add default skin
         add_skin_folder(self.skin,"default","dtml/skin/default/",globals(),encode)
-        #Add plonified skin
-        add_skin_folder(self.skin,"plonified","dtml/skin/plonified/",globals(),encode)
-        add_skin_folder(self.skin.plonified,"portlets","dtml/skin/plonified/portlets/",globals(),encode)
 
         #properties
         self._properties = (get_property_dict())
@@ -438,11 +435,8 @@ class COREBlog(ZCatalog.ZCatalog):
             except:
                 pass
 
-            message = ''
             if not title:
-                message = 'Title is required.'
-            if main_category in [0,-1]:
-                message = 'Please select main category.'
+                kw['worning_message'] = "Title is required."
 
             kw['date_created'] = lambda x=entry_date : DateTime(x)
             kw['year_created'] = lambda x=entry_date: DateTime(x).year()
@@ -455,7 +449,6 @@ class COREBlog(ZCatalog.ZCatalog):
             kw['subtitle'] = v_h(subtitle)
             kw['count_comment'] = lambda : 0
             kw['count_trackback'] = lambda : 0
-            kw['format'] = format
             if format in html_formats:
                 kw['rendered_body'] = v_b(body)
                 kw['body'] = v_b(body)
@@ -470,7 +463,7 @@ class COREBlog(ZCatalog.ZCatalog):
             kw['nocommentform'] = 1
 
             #Returns addEntryForm
-            return self.manage_addEntryForm(self,REQUEST,manage_tabs_message=message,**kw)
+            return self.manage_addEntryForm(self,REQUEST,**kw)
 
         new_id = self.getNewEntryID()
         #remove category duplications
@@ -898,16 +891,7 @@ class COREBlog(ZCatalog.ZCatalog):
             return ""
         return m_list[month-1]
 
-    def get_entry_in_category(self,category_id,consider_moderation = 1):
-        #Returns entries in category
-        l = []
-        for id in self.entry_list:
-            obj = self.getEntry(id)
-            if obj.category and obj.category[0] == category_id:
-                if not consider_moderation or obj.moderated:
-                    l.append(obj)
-        return l
-
+ 
     security.declareProtected(View, 'rev_category_entry_items')
     def rev_category_entry_items(self,category_id,start=0,count=-1,consider_moderation = 1):
         """Return list of Entry(chronological order)."""
@@ -923,18 +907,24 @@ class COREBlog(ZCatalog.ZCatalog):
         list_c = len(self.entry_list)
         if count == -1:
             count = list_c
-        return self.get_entry_in_category(int_cat,consider_moderation)[start:start+count]
+        for c in range(start,start+count):
+            if list_c <= c:
+                #index out of range
+                break
+            id = self.entry_list[c]
+            obj = self.getEntry(id)
+            if obj.category and obj.category[0] == int_cat:
+                if not consider_moderation or obj.moderated:
+                    l.append(obj)
+        return l
+
 
     security.declareProtected(View, 'category_entry_items')
     def category_entry_items(self,category_id,start=0,count=-1,consider_moderation = 1):
         """Return list of Entry."""
-        try:
-            int_cat = int(category_id)
-        except:
-            return []
-        l = self.get_entry_in_category(int_cat,consider_moderation)
+        l = self.rev_category_entry_items(category_id,start,count,consider_moderation)
         l.reverse()
-        return l[start:start+count]
+        return l
 
 
     security.declareProtected(View, 'count_entry')
@@ -1313,8 +1303,7 @@ class COREBlog(ZCatalog.ZCatalog):
         obj = self.getCategory(id)
         obj[0].edit(name,description,icon_path)
         if REQUEST:
-            return REQUEST.RESPONSE.redirect(\
-                        'manage_editSettingForm?section:int=1')
+            return REQUEST.RESPONSE.redirect('manage_categoryForm')
 
 
     security.declareProtected(ManageCOREBlog, 'manage_calculateCategory')
@@ -2060,11 +2049,6 @@ class COREBlog(ZCatalog.ZCatalog):
         except:
             return xmlrpclib.False
 
-        
-    def update_footer_prop(self):
-        prop = self.getProperty('footer')
-        self._delProperty('footer')
-        self.manage_addProperty('footer_desc',prop,'text')
 #
 # Factory method for COREBlog instance.
 #
