@@ -34,7 +34,6 @@ import Globals
 from permissions import View,ManageCOREBlog,AddCOREBlogEntries,AddCOREBlogComments,ModerateCOREBlogEntries
 from App import Management, Undo
 from AccessControl import ClassSecurityInfo
-from OFS import ZDOM
 from DateTime import DateTime
 from BTrees.IIBTree import IISet
 from BTrees.IOBTree import IOBTree
@@ -50,9 +49,9 @@ from utility import make_unique, \
                     code_euc,code_sjis,code_utf8,code_jis,code_us
 
 __doc__="""Zope Blog Product 'COREBlog:Entry'
-$Id: Entry.py,v 1.6 2005/04/30 13:27:47 ats_shib Exp $"""
+$Id: Entry.py,v 1.4 2005/02/17 12:30:22 ats_shib Exp $"""
 
-__version__='$Revision: 1.6 $'[11:-2]
+__version__='$Revision: 1.4 $'[11:-2]
 
 cc_dic = {"eucjp":code_euc,"shiftjis":code_sjis,"utf8":code_utf8,"iso2022ji":code_jis}
 
@@ -98,12 +97,10 @@ def get_rendered_body(body,format):
              r_body = restructured_text(body)
         except:
              pass
-    elif int(format) == format_plain:
-            r_body = '<br />\n'.join(body.split('\n'))
     return r_body
 
 
-class Entry(ObjectBase,Management.Tabs,Undo.UndoSupport,ZDOM.Element):
+class Entry(ObjectBase,Management.Tabs,Undo.UndoSupport):
     """Class for COREBlog Entries"""
 
     security = ClassSecurityInfo()
@@ -282,10 +279,6 @@ class Entry(ObjectBase,Management.Tabs,Undo.UndoSupport,ZDOM.Element):
 
                 return self.manage_main(self,REQUEST,**kw)
 
-    security.declareProtected(View, 'title_or_id')
-    def title_or_id(self):
-        """ Return title """
-        return self.title
 
     security.declareProtected(View, 'index_html')
     def index_html(self,ignore_moderation=0,REQUEST=None):
@@ -295,18 +288,6 @@ class Entry(ObjectBase,Management.Tabs,Undo.UndoSupport,ZDOM.Element):
         else:
             raise KeyError,self.id
 
-    security.declareProtected(View, 'CookedBody')
-    def CookedBody(self):
-        """ Return rendered body according to format """
-        return get_rendered_body(self.body,self.format)
-
-    security.declareProtected(View, 'CookedExtend')
-    def CookedExtend(self):
-        """ Return rendered extend according to format """
-        if self.extend:
-            return get_rendered_body(self.extend,self.format)
-        return ''
-
     security.declareProtected(View, 'body_size')
     def body_size(self):
         """ Entry size """
